@@ -387,7 +387,7 @@ hildon_desktop_panel_window_init (HildonDesktopPanelWindow *window)
 
 static void 
 hildon_desktop_panel_window_force_move (GtkWidget *widget, GdkEventExpose *event, gpointer data)
-{
+{ 
   hildon_desktop_panel_win_move_resize (HILDON_DESKTOP_PANEL_WINDOW (widget),TRUE,TRUE);
 }
 
@@ -453,7 +453,7 @@ hildon_desktop_panel_window_constructor (GType gtype,
   gtk_widget_show (GTK_WIDGET (HILDON_DESKTOP_WINDOW (window)->container));
 
   g_signal_connect_after (object,
-		          "expose-event",
+		          "map",
 			  G_CALLBACK (hildon_desktop_panel_window_force_move),
 			  NULL);
 
@@ -980,7 +980,8 @@ hildon_desktop_panel_size_request (GtkWidget *widget,
     position_changed = TRUE;	
   }
 
-  hildon_desktop_panel_win_move_resize (window,position_changed,size_changed);
+  if (window->priv->move)
+    hildon_desktop_panel_win_move_resize (window,position_changed,size_changed);
 }
 
 static void 
