@@ -34,10 +34,6 @@
 
 #include <glib.h>
 
-#include <hildon-widgets/hildon-banner.h>
-#include <hildon-widgets/hildon-note.h>
-#include <hildon-widgets/hildon-defines.h>
-
 #include <libhildonwm/hd-wm.h>
 
 #include "hildon-home-area.h"
@@ -335,37 +331,6 @@ hildon_home_window_show (GtkWidget *widget)
   GTK_WIDGET_CLASS (hildon_home_window_parent_class)->show (widget);
 }
 
-static gboolean
-hildon_home_window_key_press_event (GtkWidget *widget,
-                                    GdkEventKey *event)
-{
-  HildonHomeWindowPrivate *priv = HILDON_HOME_WINDOW (widget)->priv;
-
-  switch (event->keyval)
-    {
-      case HILDON_HARDKEY_MENU:
-          hildon_home_titlebar_toggle_menu (HILDON_HOME_TITLEBAR (priv->titlebar));
-          break;
-      case HILDON_HARDKEY_ESC:
-          /* FIXME: Have a signal in HomeWindow instead */
-          if (hildon_home_area_get_layout_mode (
-                                    HILDON_HOME_AREA(priv->applet_area)))
-            g_signal_emit_by_name (G_OBJECT (priv->titlebar), "layout-cancel");
-
-          break;
-      default:
-          if (GTK_WIDGET_CLASS (
-                     hildon_home_window_parent_class)->key_press_event)
-            return GTK_WIDGET_CLASS (
-                     hildon_home_window_parent_class)->key_press_event (widget,
-                                                                        event);
-          else
-            return FALSE;
-    }
-
-  return TRUE;
-}
-
 static void
 hildon_home_window_finalize (GObject *gobject)
 {
@@ -632,7 +597,6 @@ hildon_home_window_class_init (HildonHomeWindowClass *klass)
   gobject_class->get_property = hildon_home_window_get_property;
   gobject_class->finalize = hildon_home_window_finalize;
   
-  widget_class->key_press_event = hildon_home_window_key_press_event;
   widget_class->size_allocate = hildon_home_window_size_allocate;
   widget_class->expose_event = hildon_home_window_expose;
   widget_class->map = hildon_home_window_map;
@@ -788,32 +752,6 @@ hildon_home_window_get_titlebar (HildonHomeWindow *window)
   return window->priv->titlebar;
 }
 
-void
-hildon_home_window_show_information_note (HildonHomeWindow *window,
-                                          const gchar *text)
-{
-  GtkWidget *note = NULL;
-
-  note =
-    hildon_note_new_information (NULL, 
-				                 text);
-		    
-  gtk_dialog_run (GTK_DIALOG (note));
-  if (note) 
-    gtk_widget_destroy (GTK_WIDGET (note));
-}
-
-void
-hildon_home_window_show_information_banner (HildonHomeWindow *window,
-                                            const gchar *text)
-{
-  g_return_if_fail (GTK_IS_WIDGET (window) && text);
-
-  hildon_banner_show_information (GTK_WIDGET (window),
-                                  NULL,
-                                  text);
-}
-
 void
 hildon_home_window_set_desktop_dimmed (HildonHomeWindow *window,
                                        gboolean dimmed)
@@ -876,7 +814,9 @@ hildon_home_window_select_applets (HildonHomeWindow   *window)
   HildonHomeWindowPrivate *priv = window->priv;
   
   priv->selecting_applets = TRUE;
+  hildon_home_area_set_batch_add (HILDON_HOME_AREA (priv->applet_area), TRUE);
   g_signal_emit_by_name (window, "select-plugins", NULL);
+  hildon_home_area_set_batch_add (HILDON_HOME_AREA (priv->applet_area), FALSE);
   priv->selecting_applets = FALSE;
 
   if (HILDON_IS_HOME_AREA (priv->applet_area))
