@@ -37,6 +37,7 @@
 #define HD_CONTAINER_TYPE_HOME              "home"
 #define HD_CONTAINER_TYPE_PANEL_FIXED       "panel_fixed"
 #define HD_CONTAINER_TYPE_PANEL_BOX         "panel_box"
+#define HD_CONTAINER_TYPE_PANEL_EXPANDABLE  "panel_expandable"
 
 #define HD_WINDOW_ORIENTATION_TOP           "top"
 #define HD_WINDOW_ORIENTATION_BOTTOM        "bottom"
@@ -55,4 +56,6 @@
 
 #define HD_PLUGIN_CONFIG_KEY_TN             "X-task-navigator-plugin"
 
+#define HD_PLUGIN_CONFIG_KEY_SB             "X-status-bar-plugin"
+
 #endif /* __HD_CONFIG_FILES_H__ */
